==> MK_Portable(Linux_x86-gcc3)-3.10.zip: MK/xulsword/defaults/preferences/prefs.js <==
pref("extensions.xulsword.BuildID", "150105_0P");
pref("extensions.xulsword.ContributorList", "Special Thanks To:\nTroy Griffitts and the SWORD Project\n\nDevelopers:\nJohn Austin\nDavid Booth\n\nContributors:\nAbram Victorovich\nAllen Peleton\nDavid Haslam\nWolfgang Stradner");
pref("extensions.xulsword.Cross-references", "On");
pref("extensions.xulsword.DefaultCK", "spirit");
pref("extensions.xulsword.DefaultVersion", "none");
pref("extensions.xulsword.DontReadReferenceBible", false);
pref("extensions.xulsword.DontShowExceptionDialog", false);
pref("extensions.xulsword.EngineVersion", "1.7.3");
pref("extensions.xulsword.Footnotes", "On");
pref("extensions.xulsword.Headings", "On");
pref("extensions.xulsword.Hebrew Cantillation", "On");
pref("extensions.xulsword.Hebrew Vowel Points", "On");
pref("extensions.xulsword.HelpEmailAddress", "gpl.programs.info@gmail.com");
pref("extensions.xulsword.HideDisabledBooks", false);
pref("extensions.xulsword.HideDisabledViewMenuItems", false);
pref("extensions.xulsword.LibSwordURL", "ftp://ibt.org.ru/pub/xulsword/lib");
pref("extensions.xulsword.LibxulswordVersion", "1.2");
pref("extensions.xulsword.Location", "Matt.1.1");
pref("extensions.xulsword.MaximizeNoteBox1", false);
pref("extensions.xulsword.MaximizeNoteBox2", false);
pref("extensions.xulsword.MaximizeNoteBox3", false);
pref("extensions.xulsword.MinUIversion", "3.10");
pref("extensions.xulsword.MinXSMversion", "1.0");
pref("extensions.xulsword.Morphological Tags", "On");
pref("extensions.xulsword.Name", "MK");
pref("extensions.xulsword.ProblemReportURL", "http://ibt.org.ru/php/report.php");
pref("extensions.xulsword.Reference Material Links", "On");
pref("extensions.xulsword.ShowCrossrefsAtBottom", false);
pref("extensions.xulsword.ShowFootnotesAtBottom", true);
pref("extensions.xulsword.ShowUserNotesAtBottom", true);
pref("extensions.xulsword.Strong's Numbers", "On");
pref("extensions.xulsword.User Notes", "On");
pref("extensions.xulsword.Vendor", "IBT");
pref("extensions.xulsword.Verse Numbers", "On");
pref("extensions.xulsword.Version", "3.10");
pref("extensions.xulsword.Words of Christ in Red", "On");
pref("extensions.xulsword.w1.hidden", "TR;HEB;StrongsGreek;StrongsHebrew;Robinson;");
pref("extensions.xulsword.w2.hidden", "TR;HEB;StrongsGreek;StrongsHebrew;Robinson;");
pref("extensions.xulsword.w3.hidden", "TR;HEB;StrongsGreek;StrongsHebrew;Robinson;");
pref("intl.locale.matchOS", false);
pref("toolkit.defaultChromeURI", "chrome://xulsword/content/startup/startup.xul");
pref("ui.use_unity_menubar", false);

==> MK_Portable(Linux_x86-gcc3)-3.12.zip: MK/xulsword/defaults/preferences/prefs.js <==
pref("extensions.xulsword.BuildID", "150316_569P");
pref("extensions.xulsword.ContributorList", "Special Thanks To:\nTroy Griffitts and the SWORD Project\n\nDevelopers:\nJohn Austin\nDavid Booth\n\nContributors:\nAbram Victorovich\nAllen Peleton\nDavid Haslam\nWolfgang Stradner");
pref("extensions.xulsword.Cross-references", "On");
pref("extensions.xulsword.DefaultCK", "spirit");
pref("extensions.xulsword.DefaultVersion", "none");
pref("extensions.xulsword.DontReadReferenceBible", false);
pref("extensions.xulsword.DontShowExceptionDialog", false);
pref("extensions.xulsword.EngineVersion", "1.7.3");
pref("extensions.xulsword.Footnotes", "On");
pref("extensions.xulsword.Headings", "On");
pref("extensions.xulsword.Hebrew Cantillation", "On");
pref("extensions.xulsword.Hebrew Vowel Points", "On");
pref("extensions.xulsword.HelpEmailAddress", "gpl.programs.info@gmail.com");
pref("extensions.xulsword.HideDisabledBooks", false);
pref("extensions.xulsword.HideDisabledViewMenuItems", false);
pref("extensions.xulsword.LibSwordURL", "ftp://ibt.org.ru/pub/xulsword/lib");
pref("extensions.xulsword.LibxulswordVersion", "1.2.1");
pref("extensions.xulsword.Location", "Matt.1.1");
pref("extensions.xulsword.MaximizeNoteBox1", false);
pref("extensions.xulsword.MaximizeNoteBox2", false);
pref("extensions.xulsword.MaximizeNoteBox3", false);
pref("extensions.xulsword.MinUIversion", "3.10");
pref("extensions.xulsword.MinXSMversion", "1.0");
pref("extensions.xulsword.Morphological Tags", "On");
pref("extensions.xulsword.Name", "MK");
pref("extensions.xulsword.ProblemReportURL", "http://ibt.org.ru/php/report.php");
pref("extensions.xulsword.Reference Material Links", "On");
pref("extensions.xulsword.ShowCrossrefsAtBottom", false);
pref("extensions.xulsword.ShowFootnotesAtBottom", true);
pref("extensions.xulsword.ShowUserNotesAtBottom", true);
pref("extensions.xulsword.Strong's Numbers", "On");
pref("extensions.xulsword.User Notes", "On");
pref("extensions.xulsword.Vendor", "IBT");
pref("extensions.xulsword.Verse Numbers", "On");
pref("extensions.xulsword.Version", "3.12");
pref("extensions.xulsword.Words of Christ in Red", "On");
pref("extensions.xulsword.w1.hidden", "TR;HEB;StrongsGreek;StrongsHebrew;Robinson;");
pref("extensions.xulsword.w2.hidden", "TR;HEB;StrongsGreek;StrongsHebrew;Robinson;");
pref("extensions.xulsword.w3.hidden", "TR;HEB;StrongsGreek;StrongsHebrew;Robinson;");
pref("intl.locale.matchOS", false);
pref("toolkit.defaultChromeURI", "chrome://xulsword/content/startup/startup.xul");
pref("ui.use_unity_menubar", false);
